@@ -52,8 +52,10 @@ class TestReconstructorRevert(ECProbeTest):
 
         # PUT object
         contents = Body()
-        headers = {'x-object-meta-foo': 'meta-foo'}
-        headers_post = {'x-object-meta-bar': 'meta-bar'}
+        headers = {'x-object-meta-foo': 'meta-foo',
+                   u'x-object-meta-non-ascii-value1': u'meta-f\xf6\xf6'}
+        headers_post = {'x-object-meta-bar': 'meta-bar',
+                        u'x-object-meta-non-ascii-value2': u'meta-b\xe4r'}
         client.put_object(self.url, self.token, self.container_name,
                           self.object_name, contents=contents,
                           headers=headers)
@@ -86,7 +88,7 @@ class TestReconstructorRevert(ECProbeTest):
 
         # fire up reconstructor on handoff nodes only
         for hnode in hnodes:
-            hnode_id = (hnode['port'] % 100) // 10
+            hnode_id = self.config_number(hnode)
             self.reconstructor.once(number=hnode_id)
 
         # first three primaries have data again
@@ -398,7 +400,7 @@ class TestReconstructorRevert(ECProbeTest):
 
         # fire up reconstructor on handoff node only; commit_window is
         # set to zero to ensure the nondurable handoff frag is purged
-        hnode_id = (hnodes[0]['port'] % 100) // 10
+        hnode_id = self.config_number(hnodes[0])
         self.run_custom_daemon(
             ObjectReconstructor, 'object-reconstructor', hnode_id,
             {'commit_window': '0'})
